Learn R Programming

cif (version 0.1.1)

Wald.mls: Wald test for Multivariate Least-Squares regression

Description

Wald test for multivariate Least-Squares regression

Usage

Wald.mls(mlsresults)

Arguments

mlsresults

output of mls, mlsresults<-mls(y, x, df_flag)

Value

wald table of Wald tests on significance of single regressors and pvalues based on chi square distribution

References

Berta et al. 2020